==> wallaroo-2023.2.1rc1.tar.gz: wallaroo-2023.2.1rc1/wallaroo/wallaroo_ml_ops_api_client/models/assays_create_response_200.py <==
from typing import Any, Dict, List, Type, TypeVar

import attr

T = TypeVar("T", bound="AssaysCreateResponse200")


@attr.s(auto_attribs=True)
class AssaysCreateResponse200:
    """  Successful assay creation response.

        Attributes:
            assay_id (int):  New assay identifier.
     """

    assay_id: int
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)


    def to_dict(self) -> Dict[str, Any]:
        assay_id = self.assay_id

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "assay_id": assay_id,
        })

        return field_dict



    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        assay_id = d.pop("assay_id")

        assays_create_response_200 = cls(
            assay_id=assay_id,
        )

        assays_create_response_200.additional_properties = d
        return assays_create_response_200

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> wallaroo-2024.4.3.tar.gz: wallaroo-2024.4.3/wallaroo/wallaroo_ml_ops_api_client/models/assays_create_response_200.py <==
from typing import Any, Dict, List, Type, TypeVar

from attrs import (
    define as _attrs_define,
    field as _attrs_field,
)

T = TypeVar("T", bound="AssaysCreateResponse200")


@_attrs_define
class AssaysCreateResponse200:
    """Successful assay creation response.

    Attributes:
        assay_id (int):  New assay identifier.
    """

    assay_id: int
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        assay_id = self.assay_id

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "assay_id": assay_id,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        assay_id = d.pop("assay_id")

        assays_create_response_200 = cls(
            assay_id=assay_id,
        )

        assays_create_response_200.additional_properties = d
        return assays_create_response_200

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
